# apeek

`apeek` is a package for creating audio waveform previews.

The library installs a command `apeek` for generating waveform overviews with Unicode 
block characters for display in a terminal.

![Screenshot](docs/apeek.png)
